package com.ruoyi.system.service;

import com.ruoyi.system.domain.SysMqttUser;

import java.util.List;

/**
 * mqtt用户Service接口
 *
 * @author Duke_yzl
 * @date 2023-06-30
 */
public interface ISysMqttUserService
{
    /**
     * 查询mqtt用户
     *
     * @param id mqtt用户主键
     * @return mqtt用户
     */
    public SysMqttUser selectSysMqttUserById(Long id);

    /**
     * 查询mqtt用户列表
     *
     * @param sysMqttUser mqtt用户
     * @return mqtt用户集合
     */
    public List<SysMqttUser> selectSysMqttUserList(SysMqttUser sysMqttUser);

    /**
     * 新增mqtt用户
     *
     * @param sysMqttUser mqtt用户
     * @return 结果
     */
    public boolean insertSysMqttUser(SysMqttUser sysMqttUser);

    /**
     * 修改mqtt用户
     *
     * @param sysMqttUser mqtt用户
     * @return 结果
     */
    public boolean updateSysMqttUser(SysMqttUser sysMqttUser);

    /**
     * 批量删除mqtt用户
     *
     * @param ids 需要删除的mqtt用户主键集合
     * @return 结果
     */
    public boolean deleteSysMqttUserByIds(Long[] ids);

    /**
     * 删除mqtt用户信息
     *
     * @param id mqtt用户主键
     * @return 结果
     */
    public boolean deleteSysMqttUserById(Long id);
}
